==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-clock/clock_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation type="unfinished">Postavke sata</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation type="unfinished">Vrijeme</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation type="unfinished">&amp;Pokaži sekunde</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation type="unfinished">12 &amp;satni stil</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation type="unfinished">&amp;Koristi UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation type="unfinished">&amp;Ne pokazuj datum</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation type="unfinished">Pokaži datum &amp;prije vremena</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation type="unfinished">Pokaži datum &amp;poslije vremena</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation type="unfinished">Pokaži datum ispod u novom &amp;retku</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished">Prvi dan u tjednu u kalendaru</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation type="unfinished">Orijentacija</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation type="unfinished">Format &amp;datuma</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation type="unfinished">Unesite prilagođeni format datuma</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished">Interpretirani dijelovi formata datuma su:

d	dan kao broj bez početne nule (1 to 31)
dd	dan kao broj sa početnom nulom (01 to 31)
ddd	skraćeno lokalizirano ime dana (npr. &apos;Pon&apos; do &apos;Ned&apos;).
dddd	dugo lokalizirano ime  (npr. &apos;Ponedjeljak&apos; do &apos;Nedjelje&apos;).
M	mjesec kao broj bezpočetne nule (1-12)
MM	mjesec kao broj sa početnom nulom (01-12)
MMM	skraćeno lokalizirano ime mjeseca (npr. &apos;Sij&apos; do &apos;Pro&apos;).
MMMM	dugo lokalizirano ime mjeseca (npr. &apos;Siječanj&apos; do &apos;Prosinac&apos;).
yy	godina sa dvoznamenkastim brojemr (00-99)
yyyy	godina kao četveroznamenkasti broj

Svi ostali znakovi unosa biti će tretirani kao tekst.
Bilo koji dio znakova  koji su zatvoreni jednostrukim navodnicima (&apos;)
će također biti interpretirani kao tekst.i neće biti korišteni kao izraz


Prilagođeni format datuma:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation type="unfinished">Postavke sata</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation type="unfinished">Vrijeme</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation type="unfinished">&amp;Pokaži sekunde</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation type="unfinished">12 &amp;satni stil</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation type="unfinished">&amp;Koristi UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation type="unfinished">&amp;Ne pokazuj datum</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation type="unfinished">Pokaži datum &amp;prije vremena</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation type="unfinished">Pokaži datum &amp;poslije vremena</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation type="unfinished">Pokaži datum ispod u novom &amp;retku</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished">Prvi dan u tjednu u kalendaru</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation type="unfinished">Orijentacija</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation type="unfinished">Format &amp;datuma</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation type="unfinished">Unesite prilagođeni format datuma</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished">Interpretirani dijelovi formata datuma su:

d	dan kao broj bez početne nule (1 to 31)
dd	dan kao broj sa početnom nulom (01 to 31)
ddd	skraćeno lokalizirano ime dana (npr. &apos;Pon&apos; do &apos;Ned&apos;).
dddd	dugo lokalizirano ime  (npr. &apos;Ponedjeljak&apos; do &apos;Nedjelje&apos;).
M	mjesec kao broj bezpočetne nule (1-12)
MM	mjesec kao broj sa početnom nulom (01-12)
MMM	skraćeno lokalizirano ime mjeseca (npr. &apos;Sij&apos; do &apos;Pro&apos;).
MMMM	dugo lokalizirano ime mjeseca (npr. &apos;Siječanj&apos; do &apos;Prosinac&apos;).
yy	godina sa dvoznamenkastim brojemr (00-99)
yyyy	godina kao četveroznamenkasti broj

Svi ostali znakovi unosa biti će tretirani kao tekst.
Bilo koji dio znakova  koji su zatvoreni jednostrukim navodnicima (&apos;)
će također biti interpretirani kao tekst.i neće biti korišteni kao izraz


Prilagođeni format datuma:</translation>
    </message>
</context>
</TS>
